@@ -86,7 +86,7 @@ void AbstractAccount::registerApplication(const QString &appName, const QString
     };
     const QJsonDocument doc(obj);
 
-    post(regUrl, doc, false, [=](QNetworkReply *reply) {
+    post(regUrl, doc, false, this, [=](QNetworkReply *reply) {
         if (!reply->isFinished()) {
             qCDebug(TOKODON_LOG) << "not finished";
             return;
@@ -188,7 +188,7 @@ void AbstractAccount::setToken(const QString &authcode)
     q.addQueryItem("grant_type", "authorization_code");
     q.addQueryItem("code", authcode);
 
-    post(tokenUrl, q, false, [=](QNetworkReply *reply) {
+    post(tokenUrl, q, false, this, [=](QNetworkReply *reply) {
         auto data = reply->readAll();
         auto doc = QJsonDocument::fromJson(data);
 
@@ -199,125 +199,12 @@ void AbstractAccount::setToken(const QString &authcode)
     });
 }
 
-void AbstractAccount::fetchAccount(qint64 id, bool excludeReplies, const QString &timelineName, const QString &fromId)
-{
-    auto thread = std::make_shared<QList<std::shared_ptr<Post>>>();
-    // Fetch pinned posts if we are starting from the top
-    const bool fetchPinned = fromId.isNull();
-
-    QUrl uriStatus(m_instance_uri);
-    uriStatus.setPath(QString("/api/v1/accounts/%1/statuses").arg(id));
-    auto statusQuery = QUrlQuery();
-    if (excludeReplies) {
-        statusQuery.addQueryItem("exclude_replies", "true");
-    }
-    if (!fetchPinned) {
-        statusQuery.addQueryItem("max_id", fromId);
-    }
-    if (!statusQuery.isEmpty()) {
-        uriStatus.setQuery(statusQuery);
-    }
-
-    QUrl uriPinned(m_instance_uri);
-    uriPinned.setPath(QString("/api/v1/accounts/%1/statuses").arg(id));
-    uriPinned.setQuery(QUrlQuery{{"pinned", "true"}});
-
-    auto onFetchPinned = [=](QNetworkReply *reply) {
-        const auto data = reply->readAll();
-        const auto doc = QJsonDocument::fromJson(data);
-
-        if (!doc.isArray()) {
-            return;
-        }
-
-        int i = 0;
-        const auto array = doc.array();
-        for (const auto &value : array) {
-            const QJsonObject obj = value.toObject();
-
-            auto p = std::make_shared<Post>(this, obj);
-            thread->insert(i, p);
-            i++;
-        }
-
-        Q_EMIT fetchedTimeline(timelineName, *thread);
-    };
-
-    auto onFetchAccount = [=](QNetworkReply *reply) {
-        const auto data = reply->readAll();
-        const auto doc = QJsonDocument::fromJson(data);
-
-        if (!doc.isArray()) {
-            return;
-        }
-
-        const auto array = doc.array();
-        for (const auto &value : array) {
-            const QJsonObject obj = value.toObject();
-
-            auto p = std::make_shared<Post>(this, obj);
-            thread->push_back(p);
-        }
-
-        if (fetchPinned) {
-            get(uriPinned, true, onFetchPinned);
-        } else {
-            Q_EMIT fetchedTimeline(timelineName, *thread);
-        }
-    };
-
-    get(uriStatus, true, onFetchAccount);
-}
-
-void AbstractAccount::fetchTimeline(const QString &original_name, const QString &from_id)
-{
-    QString timelineName = QString(original_name);
-    bool local = timelineName == "public";
-
-    // federated timeline is really "public" without local set
-    if (timelineName == "federated") {
-        timelineName = "public";
-    }
-
-    QUrlQuery q;
-    if (local) {
-        q.addQueryItem("local", "true");
-    }
-    if (!from_id.isEmpty()) {
-        q.addQueryItem("max_id", from_id);
-    }
-
-    auto uri = apiUrl(QString("/api/v1/timelines/%1").arg(timelineName));
-    uri.setQuery(q);
-
-    get(uri, true, [=](QNetworkReply *reply) {
-        QList<std::shared_ptr<Post>> posts;
-
-        const auto data = reply->readAll();
-        const auto doc = QJsonDocument::fromJson(data);
-
-        if (!doc.isArray()) {
-            return;
-        }
-
-        const auto array = doc.array();
-        for (const auto &value : array) {
-            QJsonObject obj = value.toObject();
-
-            const auto p = std::make_shared<Post>(this, obj);
-            posts.push_back(p);
-        }
-
-        Q_EMIT fetchedTimeline(original_name, posts);
-    });
-}
-
 void AbstractAccount::postStatus(Post *p)
 {
     QUrl post_status_url = apiUrl("/api/v1/statuses");
     auto doc = p->toJsonDocument();
 
-    post(post_status_url, doc, true, [=](QNetworkReply *reply) {
+    post(post_status_url, doc, true, this, [=](QNetworkReply *reply) {
         auto data = reply->readAll();
         auto doc = QJsonDocument::fromJson(data);
         auto obj = doc.object();
@@ -325,20 +212,20 @@ void AbstractAccount::postStatus(Post *p)
     });
 }
 
-void AbstractAccount::mutatePost(std::shared_ptr<Post> p, const QString &verb, bool deliver_home)
+void AbstractAccount::mutatePost(Post *p, const QString &verb, bool deliver_home)
 {
     const QUrl mutation_url = apiUrl(QString("/api/v1/statuses/%1/%2").arg(p->inReplyTo(), verb));
     const QJsonDocument doc;
 
-    post(mutation_url, doc, true, [=](QNetworkReply *reply) {
+    post(mutation_url, doc, true, this, [=](QNetworkReply *reply) {
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
         if (deliver_home) {
-            QList<std::shared_ptr<Post>> posts;
+            QList<Post *> posts;
             auto obj = doc.object();
 
-            auto p = std::make_shared<Post>(this, obj);
+            auto p = new Post(this, obj, this);
             posts.push_back(p);
 
             Q_EMIT fetchedTimeline("home", posts);
@@ -346,22 +233,22 @@ void AbstractAccount::mutatePost(std::shared_ptr<Post> p, const QString &verb, b
     });
 }
 
-void AbstractAccount::favorite(std::shared_ptr<Post> p)
+void AbstractAccount::favorite(Post *p)
 {
     mutatePost(p, "favourite");
 }
 
-void AbstractAccount::unfavorite(std::shared_ptr<Post> p)
+void AbstractAccount::unfavorite(Post *p)
 {
     mutatePost(p, "unfavourite");
 }
 
-void AbstractAccount::repeat(std::shared_ptr<Post> p)
+void AbstractAccount::repeat(Post *p)
 {
     mutatePost(p, "reblog", true);
 }
 
-void AbstractAccount::unrepeat(std::shared_ptr<Post> p)
+void AbstractAccount::unrepeat(Post *p)
 {
     mutatePost(p, "unreblog");
 }
@@ -418,17 +305,17 @@ void AbstractAccount::fetchInstanceMetadata()
     QUrl instance_url = apiUrl("/api/v1/instance");
     QUrl pleroma_info = apiUrl("/nodeinfo/2.1.json");
 
-    get(instance_url, false, [=](QNetworkReply *reply) {
+    get(instance_url, false, this, [=](QNetworkReply *reply) {
         if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute))
             return;
 
-        auto data = reply->readAll();
-        auto doc = QJsonDocument::fromJson(data);
+        const auto data = reply->readAll();
+        const auto doc = QJsonDocument::fromJson(data);
 
         if (!doc.isObject())
             return;
 
-        auto obj = doc.object();
+        const auto obj = doc.object();
 
         if (obj.contains("max_toot_chars")) {
             m_maxPostLength = (unsigned)obj["max_toot_chars"].toInt();
@@ -445,9 +332,9 @@ void AbstractAccount::fetchInstanceMetadata()
     m_instance_name = QString("social");
     Q_EMIT fetchedInstanceMetadata();
 
-    get(pleroma_info, false, [=](QNetworkReply *reply) {
-        auto data = reply->readAll();
-        auto doc = QJsonDocument::fromJson(data);
+    get(pleroma_info, false, this, [=](QNetworkReply *reply) {
+        const auto data = reply->readAll();
+        const auto doc = QJsonDocument::fromJson(data);
 
         m_allowedContentTypes = parsePleromaInfo(doc);
         Q_EMIT fetchedInstanceMetadata();
@@ -475,9 +362,9 @@ QUrl AbstractAccount::streamingUrl(const QString &stream)
 
 void AbstractAccount::handleUpdate(const QJsonDocument &doc, const QString &target)
 {
-    QList<std::shared_ptr<Post>> posts;
+    QList<Post *> posts;
     const auto obj = doc.object();
-    const auto p = std::make_shared<Post>(this, obj);
+    const auto p = new Post(this, obj, this);
     posts.push_back(p);
 
     Q_EMIT fetchedTimeline(target, posts);
@@ -517,7 +404,7 @@ void AbstractAccount::executeAction(Identity *identity, AccountAction accountAct
     QUrl url = apiUrl(api_url);
     const QJsonDocument doc(extraArguments);
 
-    post(url, doc, true, [=](QNetworkReply *reply) {
+    post(url, doc, true, this, [=](QNetworkReply *reply) {
         auto doc = QJsonDocument::fromJson(reply->readAll());
         auto jsonObj = doc.object();
 
@@ -620,5 +507,5 @@ void AbstractAccount::updateAttachment(Attachment *a)
         {"description", a->m_description},
     };
     const QJsonDocument doc(obj);
-    put(attachementUrl, doc, true, nullptr);
+    put(attachementUrl, doc, true, this, nullptr);
 }
