@@ -3,7 +3,10 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "accountmanager.h"
+#include "account.h"
 #include "networkaccessmanagerfactory.h"
+#include "accountmodel.h"
+#include "config.h"
 
 AccountManager::AccountManager(QObject *parent)
     : QAbstractListModel(parent)
@@ -36,9 +39,11 @@ QVariant AccountManager::data(const QModelIndex &index, int role) const
     auto account = m_accounts.at(index.row());
     switch (role) {
     case Qt::DisplayRole:
-        return account->identity().m_display_name;
+        return account->identity().displayNameHtml();
     case DescriptionRole:
-        return account->identity().m_acct;
+        return account->identity().account();
+    case InstanceRole:
+        return account->instanceName();
     case AccountRole:
         return QVariant::fromValue(m_accounts[index.row()]);
     }
@@ -57,6 +62,7 @@ QHash<int, QByteArray> AccountManager::roleNames() const
         {Qt::DisplayRole, QByteArrayLiteral("display")},
         {AccountRole, QByteArrayLiteral("account")},
         {DescriptionRole, QByteArrayLiteral("description")},
+        {InstanceRole, QByteArrayLiteral("instance")},
     };
 }
 
@@ -66,7 +72,7 @@ AccountManager &AccountManager::instance()
     return accountManager;
 }
 
-Account *AccountManager::createNewAccount(const QString &username, const QString &instanceUri, bool ignoreSslErrors)
+AbstractAccount *AccountManager::createNewAccount(const QString &username, const QString &instanceUri, bool ignoreSslErrors)
 {
     return new Account(username, instanceUri, m_qnam, ignoreSslErrors, this);
 }
@@ -76,21 +82,19 @@ bool AccountManager::hasAccounts() const
     return m_accounts.size() > 0;
 }
 
-void AccountManager::addAccount(Account *account)
+void AccountManager::addAccount(AbstractAccount *account)
 {
     beginInsertRows(QModelIndex(), m_accounts.size(), m_accounts.size());
     m_accounts.append(account);
     endInsertRows();
 
     Q_EMIT accountAdded(account);
-    selectAccount(account);
-
     connect(account, &Account::identityChanged, this, &AccountManager::childIdentityChanged);
     connect(account, &Account::authenticated, this, [this]() {
         Q_EMIT dataChanged(index(0, 0), index(m_accounts.size() - 1, 0));
     });
 
-    connect(account, &Account::fetchedTimeline, this, [this, account](QString original_name, QList<std::shared_ptr<Post>> posts) {
+    connect(account, &Account::fetchedTimeline, this, [this, account](QString original_name, QList<Post *> posts) {
         Q_EMIT fetchedTimeline(account, original_name, posts);
     });
     connect(account, &Account::invalidated, this, [this, account]() {
@@ -109,12 +113,17 @@ void AccountManager::addAccount(Account *account)
     writeToSettings(settings);
 }
 
-void AccountManager::childIdentityChanged(Account *account)
+void AccountManager::childIdentityChanged(AbstractAccount *account)
 {
+    auto config = Config::self();
+    if (selectedAccount() == nullptr || account->identity().account() == config->lastUsedAccount()) {
+        selectAccount(account, false);
+    }
+
     Q_EMIT identityChanged(account);
 }
 
-void AccountManager::removeAccount(Account *account)
+void AccountManager::removeAccount(AbstractAccount *account)
 {
     const auto index = m_accounts.indexOf(account);
     beginRemoveRows(QModelIndex(), index, index);
@@ -128,7 +137,7 @@ void AccountManager::removeAccount(Account *account)
     Q_EMIT accountRemoved(account);
 }
 
-void AccountManager::selectAccount(Account *account)
+void AccountManager::selectAccount(AbstractAccount *account, bool explicitUserAction)
 {
     if (!m_accounts.contains(account)) {
         qDebug() << "WTF: attempt to select unmanaged account" << account;
@@ -137,14 +146,25 @@ void AccountManager::selectAccount(Account *account)
 
     m_selected_account = account;
 
+    if (explicitUserAction) {
+        auto config = Config::self();
+        config->setLastUsedAccount(account->identity().account());
+        config->save();
+    }
+
     Q_EMIT accountSelected(account);
 }
 
-Account *AccountManager::selectedAccount() const
+AbstractAccount *AccountManager::selectedAccount() const
 {
     return m_selected_account;
 }
 
+QVariant AccountManager::selectedAccountModel()
+{
+    return QVariant::fromValue<QAbstractListModel *>(new AccountModel(this, m_selected_account->identity().id(), m_selected_account->identity().account()));
+}
+
 int AccountManager::selectedIndex() const
 {
     for (int i = 0; i < m_accounts.length(); i++) {
