@@ -1,22 +1,23 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carlschwan@kde.org>
 // SPDX-License-Identifier: GPL-3.0-only
 
-#include "account.h"
 #include "timelinemodel.h"
 #include <qobjectdefs.h>
 
+class AbstractAccount;
+
 class AccountModel : public TimelineModel
 {
     Q_OBJECT
     Q_PROPERTY(Identity *identity READ identity NOTIFY identityChanged)
-    Q_PROPERTY(Account *account READ account NOTIFY accountChanged)
+    Q_PROPERTY(AbstractAccount *account READ account NOTIFY accountChanged)
     Q_PROPERTY(bool isSelf READ isSelf NOTIFY identityChanged)
 
 public:
     AccountModel(AccountManager *manager, qint64 id, const QString &acct, QObject *parent = nullptr);
 
     QString displayName() const override;
-    Account *account() const;
+    AbstractAccount *account() const;
     Identity *identity() const;
     bool isSelf() const;
 
@@ -27,6 +28,8 @@ Q_SIGNALS:
     void accountChanged();
 
 private:
+    void updateRelationships();
+
     std::shared_ptr<Identity> m_identity;
     qint64 m_id;
 };
