@@ -33,11 +33,13 @@
 #include "account.h"
 #include "accountmanager.h"
 #include "attachmenteditormodel.h"
+#include "blurhashimageprovider.h"
 #include "clipboard.h"
 #include "config.h"
 #include "networkaccessmanagerfactory.h"
 #include "notificationmodel.h"
 #include "post.h"
+#include "filehelper.h"
 #include "timelinemodel.h"
 
 #ifdef Q_OS_ANDROID
@@ -101,10 +103,13 @@ int main(int argc, char *argv[])
     qmlRegisterType<TimelineModel>("org.kde.kmasto", 1, 0, "TimelineModel");
     qmlRegisterType<NotificationModel>("org.kde.kmasto", 1, 0, "NotificationModel");
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Clipboard", new Clipboard);
+    qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "FileHelper", new FileHelper);
     qmlRegisterSingletonType("org.kde.kmasto", 1, 0, "About", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
         return engine->toScriptValue(KAboutData::applicationData());
-    });    qmlRegisterType<AttachmentEditorModel>("org.kde.kmasto", 1, 0, "AttachmentEditorModel");
+    });
+    qmlRegisterType<AttachmentEditorModel>("org.kde.kmasto", 1, 0, "AttachmentEditorModel");
     qRegisterMetaType<Account *>("Account*");
+    qRegisterMetaType<AbstractAccount *>("AbstractAccount*");
     qRegisterMetaType<Identity *>("Identity*");
     qRegisterMetaType<Relationship *>("Relationship*");
     qmlRegisterUncreatableType<Post>("org.kde.kmasto", 1, 0, "Post", "ENUM");
@@ -112,7 +117,6 @@ int main(int argc, char *argv[])
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    KLocalizedString::setApplicationDomain("kmasto");
     QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
 
     NetworkAccessManagerFactory namFactory;
@@ -127,6 +131,8 @@ int main(int argc, char *argv[])
 
     // Controller::instance().setAboutData(about);
 
+    engine.addImageProvider(QLatin1String("blurhash"), new BlurhashImageProvider);
+
     engine.load(QUrl(QStringLiteral("qrc:/content/ui/main.qml")));
     if (engine.rootObjects().isEmpty()) {
         return -1;
