@@ -28,6 +28,7 @@ Attachment::Attachment(Post *parent, const QJsonObject &obj)
     m_url = obj["url"].toString();
     m_preview_url = obj["preview_url"].toString();
     m_description = obj["description"].toString();
+    m_blurhash = obj["blurhash"].toString();
 
     // determine type if we can
     auto type = obj["type"].toString();
@@ -58,40 +59,50 @@ static QMap<QString, Post::Visibility> stringToVisibility = {
     {"direct", Post::Visibility::Direct},
 };
 
-Post::Post(Account *parent)
+Post::Post(AbstractAccount *account, QObject *parent)
     : QObject(parent)
-    , m_parent(parent)
+    , m_parent(account)
 {
-    QString vis_str = parent->identity().m_visibility;
-    m_visibility = stringToVisibility[vis_str];
+    QString visibilityString = account->identity().visibility();
+    m_visibility = stringToVisibility[visibilityString];
 }
 
-Post::Post(Account *parent, QJsonObject obj)
+Post::Post(AbstractAccount *account, QJsonObject obj, QObject *parent)
     : QObject(parent)
-    , m_parent(parent)
+    , m_parent(account)
     , m_visibility(Post::Visibility::Public)
 {
-    auto account_doc = obj["account"].toObject();
-    auto acct = account_doc["acct"].toString();
-    auto reblog_obj = obj["reblog"].toObject();
+    const auto account_doc = obj["account"].toObject();
+    const auto acct = account_doc["acct"].toString();
+    const auto reblog_obj = obj["reblog"].toObject();
+
+    m_original_post_id = obj["id"].toString();
 
     if (!obj.contains("reblog") || reblog_obj.isEmpty()) {
         m_repeat = false;
-        m_author_identity = m_parent->identityLookup(acct, account_doc);
+        m_authorIdentity = m_parent->identityLookup(acct, account_doc);
     } else {
         m_repeat = true;
 
         auto repeat_account_doc = reblog_obj["account"].toObject();
         auto repeat_acct = repeat_account_doc["acct"].toString();
 
-        m_author_identity = m_parent->identityLookup(repeat_acct, repeat_account_doc);
-        m_repeat_identity = m_parent->identityLookup(acct, account_doc);
+        m_authorIdentity = m_parent->identityLookup(repeat_acct, repeat_account_doc);
+        m_repeatIdentity = m_parent->identityLookup(acct, account_doc);
 
         obj = reblog_obj;
     }
 
     m_subject = obj["spoiler_text"].toString();
     m_content = obj["content"].toString();
+
+    const auto emojis = obj["emojis"].toArray();
+
+    for (const auto &emoji : emojis) {
+        const auto emojiObj = emoji.toObject();
+        m_content = m_content.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'), "<img height=\"16\" width=\"16\" src=\"" + emojiObj["static_url"].toString() + "\">");
+    }
+
     m_post_id = m_replyTargetId = obj["id"].toString();
     m_isFavorite = obj["favourited"].toBool();
     m_favoriteCount = obj["favourites_count"].toInt();
@@ -119,7 +130,7 @@ Post::Post(Account *parent, QJsonObject obj)
 
 Post::~Post()
 {
-    m_attachments.clear();
+    qDeleteAll(m_attachments);
 }
 
 void Post::addAttachments(const QJsonArray &attachments)
@@ -187,8 +198,9 @@ QJsonDocument Post::toJsonDocument() const
     obj["sensitive"] = m_isSensitive;
     obj["visibility"] = visibilityToString[m_visibility];
 
-    if (!m_replyTargetId.isEmpty())
+    if (!m_replyTargetId.isEmpty()) {
         obj["in_reply_to_id"] = m_replyTargetId;
+    }
 
     auto media_ids = QJsonArray();
     for (const auto att : qAsConst(m_attachments)) {
@@ -214,21 +226,23 @@ void Post::updateAttachment(Attachment *a)
     m_parent->updateAttachment(a);
 }
 
-static QMap<QString, Notification::Type> str_to_not_type = {{"favourite", Notification::Type::Favorite},
-                                                            {"follow", Notification::Type::Follow},
-                                                            {"mention", Notification::Type::Mention},
-                                                            {"reblog", Notification::Type::Repeat}};
+static QMap<QString, Notification::Type> str_to_not_type = {
+    {"favourite", Notification::Type::Favorite},
+    {"follow", Notification::Type::Follow},
+    {"mention", Notification::Type::Mention},
+    {"reblog", Notification::Type::Repeat},
+};
 
-Notification::Notification(Account *parent, QJsonObject &obj)
-    : m_account(parent)
+Notification::Notification(AbstractAccount *account, const QJsonObject &obj, QObject *parent)
+    : m_account(account)
 {
-    QJsonObject account = obj["account"].toObject();
-    QJsonObject status = obj["status"].toObject();
-    auto acct = account["acct"].toString();
+    const QJsonObject accountObj = obj["account"].toObject();
+    const QJsonObject status = obj["status"].toObject();
+    auto acct = accountObj["acct"].toString();
     auto type = obj["type"].toString();
 
-    m_post = std::make_shared<Post>(m_account, status);
-    m_identity = m_account->identityLookup(acct, account);
+    m_post = new Post(m_account, status, parent);
+    m_identity = m_account->identityLookup(acct, accountObj);
     m_type = str_to_not_type[type];
     m_id = obj["id"].toString().toInt();
 }
@@ -238,7 +252,7 @@ int Notification::id() const
     return m_id;
 }
 
-Account *Notification::account() const
+AbstractAccount *Notification::account() const
 {
     return m_account;
 }
@@ -248,7 +262,7 @@ Notification::Type Notification::type() const
     return m_type;
 }
 
-std::shared_ptr<Post> Notification::post() const
+Post *Notification::post() const
 {
     return m_post;
 }
@@ -355,7 +369,7 @@ QString Card::authorUrl() const
 
 QString Card::blurhash() const
 {
-    return m_card[QLatin1String("blurhas")].toString();
+    return m_card[QLatin1String("blurhash")].toString();
 }
 
 QString Card::description() const
@@ -390,7 +404,11 @@ QString Card::image() const
 
 QString Card::providerName() const
 {
-    return m_card[QLatin1String("provider_name")].toString();
+    const auto providerName = m_card[QLatin1String("provider_name")].toString();
+    if (!providerName.isEmpty()) {
+        return providerName;
+    }
+    return url().host();
 }
 
 QString Card::providerUrl() const
@@ -400,10 +418,20 @@ QString Card::providerUrl() const
 
 QString Card::title() const
 {
-    return m_card[QLatin1String("title")].toString();
+    return m_card[QLatin1String("title")].toString().trimmed();
 }
 
 QUrl Card::url() const
 {
     return QUrl::fromUserInput(m_card[QLatin1String("url")].toString());
 }
+
+std::shared_ptr<Identity> Post::authorIdentity() const
+{
+    return m_authorIdentity;
+}
+
+std::shared_ptr<Identity> Post::repeatIdentity() const
+{
+    return m_repeatIdentity;
+}
