@@ -12,14 +12,13 @@
 #include <QString>
 #include <QUrl>
 
+#include <QJsonObject>
 #include <memory>
 #include <optional>
-#include <qjsonobject.h>
-#include <qobjectdefs.h>
 
 class Post;
 class Identity;
-class Account;
+class AbstractAccount;
 
 class Card
 {
@@ -72,6 +71,7 @@ class Attachment : public QObject
     Q_PROPERTY(QString previewUrl MEMBER m_preview_url CONSTANT)
     Q_PROPERTY(QString url MEMBER m_url CONSTANT)
     Q_PROPERTY(QString description MEMBER m_description CONSTANT)
+    Q_PROPERTY(QString blurhash MEMBER m_blurhash CONSTANT)
 
 public:
     explicit Attachment(Post *parent, const QJsonObject &obj);
@@ -85,6 +85,7 @@ public:
     QString m_preview_url;
     QString m_url;
     QString m_description;
+    QString m_blurhash;
 
     void setDescription(const QString &description);
 };
@@ -100,7 +101,7 @@ public:
     Notification(const Notification &)
     {
     }
-    Notification(Account *parent, QJsonObject &obj);
+    Notification(AbstractAccount *account, const QJsonObject &obj, QObject *parent = nullptr);
 
     enum Type {
         Mention,
@@ -113,17 +114,17 @@ public:
     Q_ENUM(Type);
 
     int id() const;
-    Account *account() const;
+    AbstractAccount *account() const;
     Type type() const;
-    std::shared_ptr<Post> post() const;
+    Post *post() const;
     std::shared_ptr<Identity> identity() const;
 
 private:
     int m_id;
 
-    Account *m_account;
+    AbstractAccount *m_account = nullptr;
+    Post *m_post = nullptr;
     Type m_type;
-    std::shared_ptr<Post> m_post;
     std::shared_ptr<Identity> m_identity;
 };
 
@@ -141,8 +142,8 @@ class Post : public QObject
 public:
     Post() = delete;
     Post(const Post &) = delete;
-    Post(Account *parent);
-    Post(Account *parent, QJsonObject obj);
+    Post(AbstractAccount *account, QObject *parent = nullptr);
+    Post(AbstractAccount *account, QJsonObject obj, QObject *parent = nullptr);
     ~Post();
 
     enum Visibility {
@@ -153,9 +154,10 @@ public:
     };
     Q_ENUM(Visibility)
 
-    Account *m_parent;
-    std::shared_ptr<Identity> m_author_identity;
-    std::shared_ptr<Identity> m_repeat_identity;
+    AbstractAccount *m_parent;
+
+    std::shared_ptr<Identity> authorIdentity() const;
+    std::shared_ptr<Identity> repeatIdentity() const;
 
     QString subject() const;
     void setSubject(const QString &subject);
@@ -188,6 +190,7 @@ public:
 
     QDateTime m_published_at;
     QString m_post_id;
+    QString m_original_post_id;
     QUrl m_link;
     QString m_content;
     QString m_subject;
@@ -223,6 +226,8 @@ Q_SIGNALS:
 private:
     QString m_replyTargetId;
     std::optional<Card> m_card;
+    std::shared_ptr<Identity> m_authorIdentity;
+    std::shared_ptr<Identity> m_repeatIdentity;
 };
 
 Q_DECLARE_METATYPE(Card)
