@@ -3,7 +3,9 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "threadmodel.h"
+#include "abstractaccount.h"
 #include <KLocalizedString>
+#include <QJsonObject>
 
 ThreadModel::ThreadModel(AccountManager *manager, const QString &postId, QObject *parent)
     : TimelineModel(parent)
@@ -40,8 +42,8 @@ void ThreadModel::fillTimeline(const QString &from_id)
     m_fetching = true;
 
     auto statusUrl = m_account->apiUrl(QString("/api/v1/statuses/%1").arg(m_postId));
-    auto contextUrl =m_account->apiUrl(QString("/api/v1/statuses/%1/context").arg(m_postId));
-    auto thread = std::make_shared<QList<std::shared_ptr<Post>>>();
+    auto contextUrl = m_account->apiUrl(QString("/api/v1/statuses/%1/context").arg(m_postId));
+    auto thread = std::make_shared<QList<Post *>>();
 
     auto onFetchContext = [=](QNetworkReply *reply) {
         const auto data = reply->readAll();
@@ -60,7 +62,7 @@ void ThreadModel::fillTimeline(const QString &from_id)
             }
 
             const auto anc_obj = anc.toObject();
-            const auto p = std::make_shared<Post>(m_account, anc_obj);
+            const auto p = new Post(m_account, anc_obj, this);
 
             thread->push_front(p);
         }
@@ -73,7 +75,7 @@ void ThreadModel::fillTimeline(const QString &from_id)
             }
 
             const auto desc_obj = desc.toObject();
-            const auto p = std::make_shared<Post>(m_account, desc_obj);
+            const auto p = new Post(m_account, desc_obj, this);
 
             thread->push_back(p);
         }
@@ -92,13 +94,13 @@ void ThreadModel::fillTimeline(const QString &from_id)
             return;
         }
 
-        const auto p = std::make_shared<Post>(m_account, obj);
+        const auto p = new Post(m_account, obj, this);
         thread->push_front(p);
 
-        m_account->get(contextUrl, true, onFetchContext);
+        m_account->get(contextUrl, true, this, onFetchContext);
     };
 
-    m_account->get(statusUrl, true, onFetchStatus);
+    m_account->get(statusUrl, true, this, onFetchStatus);
 }
 
 bool ThreadModel::canFetchMore(const QModelIndex &parent) const
