@@ -3,11 +3,14 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "timelinemodel.h"
+#include "abstractaccount.h"
 #include "abstracttimelinemodel.h"
 #include "accountmodel.h"
+#include "identity.h"
 #include "threadmodel.h"
 #include <KLocalizedString>
 #include <QtMath>
+#include <QUrlQuery>
 
 TimelineModel::TimelineModel(QObject *parent)
     : AbstractTimelineModel(parent)
@@ -29,6 +32,9 @@ QString TimelineModel::displayName() const
 {
     if (m_timelineName == "home") {
         if (m_manager && m_manager->rowCount() > 1) {
+            if (m_manager->selectedAccount() == nullptr) {
+                return i18n("Loading");
+            }
             return i18nc("@title", "Home (%1)", m_manager->selectedAccount()->username());
         } else {
             return i18nc("@title", "Home");
@@ -56,20 +62,8 @@ void TimelineModel::setAccountManager(AccountManager *accountManager)
 
     Q_EMIT accountManagerChanged();
 
-    QObject::connect(m_manager, &AccountManager::accountSelected, this, [=](Account *account) {
-        if (m_account == account) {
-            return;
-        }
-        m_account = account;
-
-        beginResetModel();
-        m_timeline.clear();
-        endResetModel();
-
-        fillTimeline();
-    });
     QObject::connect(m_manager, &AccountManager::fetchedTimeline, this, &TimelineModel::fetchedTimeline);
-    QObject::connect(m_manager, &AccountManager::invalidated, this, [=](Account *account) {
+    QObject::connect(m_manager, &AccountManager::invalidated, this, [=](AbstractAccount *account) {
         if (m_account == account) {
             qDebug() << "Invalidating account" << account;
 
@@ -100,11 +94,52 @@ void TimelineModel::fillTimeline(const QString &from_id)
         return;
     }
 
+    if (m_fetching) {
+        return;
+    }
     m_fetching = true;
     Q_EMIT fetchingChanged();
 
     if (m_account) {
-        m_account->fetchTimeline(m_timelineName, from_id);
+        QString timelineName = m_timelineName;
+        bool local = timelineName == "public";
+
+        // federated timeline is really "public" without local set
+        if (timelineName == "federated") {
+            timelineName = "public";
+        }
+
+        QUrlQuery q;
+        if (local) {
+            q.addQueryItem("local", "true");
+        }
+        if (!from_id.isEmpty()) {
+            q.addQueryItem("max_id", from_id);
+        }
+
+        auto uri = m_account->apiUrl(QString("/api/v1/timelines/%1").arg(m_timelineName));
+        uri.setQuery(q);
+
+        m_account->get(uri, true, this, [this, uri](QNetworkReply *reply) {
+            QList<Post *> posts;
+
+            const auto data = reply->readAll();
+            const auto doc = QJsonDocument::fromJson(data);
+
+            if (!doc.isArray()) {
+                return;
+            }
+
+            const auto array = doc.array();
+            for (const auto &value : array) {
+                const QJsonObject obj = value.toObject();
+
+                const auto p = new Post(m_account, obj, this);
+                posts.push_back(p);
+            }
+
+            fetchedTimeline(m_account, m_timelineName, posts);
+        });
     }
 }
 
@@ -117,7 +152,7 @@ void TimelineModel::fetchMore(const QModelIndex &parent)
 
     auto p = m_timeline.last();
 
-    fillTimeline(p->m_post_id);
+    fillTimeline(p->m_original_post_id);
 }
 
 bool TimelineModel::canFetchMore(const QModelIndex &parent) const
@@ -133,7 +168,7 @@ bool TimelineModel::canFetchMore(const QModelIndex &parent) const
     return true;
 }
 
-void TimelineModel::fetchedTimeline(Account *account, const QString &original_name, const QList<std::shared_ptr<Post>> &posts)
+void TimelineModel::fetchedTimeline(AbstractAccount *account, const QString &original_name, const QList<Post *> &posts)
 {
     m_fetching = false;
     Q_EMIT fetchingChanged();
@@ -184,7 +219,7 @@ int TimelineModel::rowCount(const QModelIndex &parent) const
 }
 
 // this is even more extremely cursed
-std::shared_ptr<Post> TimelineModel::internalData(const QModelIndex &index) const
+Post *TimelineModel::internalData(const QModelIndex &index) const
 {
     int row = index.row();
     return m_timeline[row];
@@ -206,11 +241,11 @@ QVariant TimelineModel::data(const QModelIndex &index, int role) const
     case Qt::DisplayRole:
         return p->m_content;
     case AvatarRole:
-        return p->m_author_identity->m_avatarUrl;
+        return p->authorIdentity()->avatarUrl();
     case AuthorDisplayNameRole:
-        return p->m_author_identity->m_display_name;
+        return p->authorIdentity()->displayNameHtml();
     case AuthorIdRole:
-        return p->m_author_identity->m_acct;
+        return p->authorIdentity()->account();
     case PublishedAtRole:
         return p->m_published_at;
     case WasRebloggedRole:
@@ -218,13 +253,13 @@ QVariant TimelineModel::data(const QModelIndex &index, int role) const
     case MentionsRole:
         return p->mentions();
     case RebloggedDisplayNameRole:
-        if (p->m_repeat_identity) {
-            return p->m_repeat_identity->m_display_name;
+        if (p->repeatIdentity()) {
+            return p->repeatIdentity()->displayNameHtml();
         }
         return {};
     case RebloggedIdRole:
-        if (p->m_repeat_identity) {
-            return p->m_repeat_identity->m_acct;
+        if (p->repeatIdentity()) {
+            return p->repeatIdentity()->account();
         }
         return {};
     case RebloggedRole:
@@ -253,7 +288,7 @@ QVariant TimelineModel::data(const QModelIndex &index, int role) const
     case ThreadModelRole:
         return QVariant::fromValue<QAbstractListModel *>(new ThreadModel(m_manager, p->m_post_id));
     case AccountModelRole:
-        return QVariant::fromValue<QAbstractListModel *>(new AccountModel(m_manager, p->m_author_identity->m_id, p->m_author_identity->m_acct));
+        return QVariant::fromValue<QAbstractListModel *>(new AccountModel(m_manager, p->authorIdentity()->id(), p->authorIdentity()->account()));
     case RelativeTimeRole: {
         const auto current = QDateTime::currentDateTime();
         auto secsTo = p->m_published_at.secsTo(current);
